.. include:: links.inc

.. _sec-video-tutorial:

Video Tutorials
===============

.. only:: html

   .. contents:: Table of Contents
      :local:
      :backlinks: top

The following videos are available: 

* `Introduction to SfePy`_
